"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.onFileAfterBatchCreateHook = void 0;
var _error = _interopRequireDefault(require("@webiny/error"));
var _createRecordPayload = require("../../utils/createRecordPayload");
const onFileAfterBatchCreateHook = ({
  fileManager,
  aco
}) => {
  /**
   * Intercept file batch creation and create a new search records.
   */
  fileManager.onFileAfterBatchCreate.subscribe(async ({
    files,
    meta
  }) => {
    try {
      for (const file of files) {
        if (file.meta.private) {
          // Skipping ACO search record creation while file is marked as private
          continue;
        }
        const payload = (0, _createRecordPayload.createFileRecordPayload)(file, meta);
        await aco.search.create(payload);
      }
    } catch (error) {
      throw _error.default.from(error, {
        message: "Error while executing onFileAfterBatchCreateHook hook",
        code: "ACO_AFTER_FILE_BATCH_CREATE_HOOK"
      });
    }
  });
};
exports.onFileAfterBatchCreateHook = onFileAfterBatchCreateHook;