"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.onFileAfterCreateHook = void 0;
var _error = _interopRequireDefault(require("@webiny/error"));
var _createRecordPayload = require("../../utils/createRecordPayload");
const onFileAfterCreateHook = ({
  fileManager,
  aco
}) => {
  /**
   * Intercept file creation and create a new search record.
   */
  fileManager.onFileAfterCreate.subscribe(async ({
    file,
    meta
  }) => {
    try {
      if (file.meta.private) {
        // Skipping ACO search record creation while file is marked as private
        return;
      }
      const payload = (0, _createRecordPayload.createFileRecordPayload)(file, meta);
      await aco.search.create(payload);
    } catch (error) {
      throw _error.default.from(error, {
        message: "Error while executing onFileAfterCreateHook hook",
        code: "ACO_AFTER_FILE_CREATE_HOOK"
      });
    }
  });
};
exports.onFileAfterCreateHook = onFileAfterCreateHook;